@@ -26,8 +26,8 @@
 
 #include <X11/Xlib.h>
 
-#define PATH_NAME "/org/handhelds/gpe/hotplug"
-#define SIGNAL_NAME "org.handhelds.gpe.hotplug.HotplugEvent"
+#define PATH_NAME "org.handhelds.gpe.hotplug"
+#define SIGNAL_NAME "HotplugEvent"
 
 #define _(x) gettext(x)
 
